TransactionPayload class abstract
An enum of the possible transaction payloads
Properties:
typefunction_- Entry function id is string representation of a entry function defined on-chain. Format:{address}::{module name}::{function name}Bothmodule nameandfunction nameare case-sensitive.typeArguments- Type arguments of the functionarguments- Arguments of the functioncodemodulesmultisigAddress- A hex encoded 32 byte Aptos account address. This is represented in a string as a 64 character hex string, sometimes shortened by stripping leading 0s, and adding a 0x. For example, address 0x0000000000000000000000000000000000000000000000000000000000000001 is represented as 0x1.transactionPayload
- Available extensions
- Annotations
-
- @BuiltValue.new()
Constructors
- TransactionPayload([void updates(TransactionPayloadBuilder b)])
-
factory
Properties
- discriminatorValue → String?
-
Available on TransactionPayload, provided by the TransactionPayloadDiscriminatorExt extension
no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- oneOf → OneOf
-
One Of TransactionPayloadEntryFunctionPayload, TransactionPayloadModuleBundlePayload, TransactionPayloadMultisigPayload, TransactionPayloadScriptPayload
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(TransactionPayloadBuilder)) → TransactionPayload -
Rebuilds the instance.
inherited
-
toBuilder(
) → TransactionPayloadBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
TransactionPayload> -
no setter
Constants
- discriminatorFieldName → const String
-
discriminatorMapping
→ const Map<
String, Type>